package io.fabric8.component.jdbc;

import javax.sql.DataSource;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.concurrent.TimeUnit;

public class InitDatabase {

	private DataSource srcDataSource;
	private DataSource trgDataSource;

	public DataSource getSrcDataSource() {
		return srcDataSource;
	}

	public void setSrcDataSource(DataSource srcDataSource) {
		this.srcDataSource = srcDataSource;
	}

	public DataSource getTrgDataSource() {
		return trgDataSource;
	}

	public void setTrgDataSource(DataSource trgDataSource) {
		this.trgDataSource = trgDataSource;
	}

	private void initDatabaseSrc(DataSource dataSource) throws SQLException {
		System.out.println("Before getConnection Src");
		Connection db = null;
		SQLException ex = null;
		long start = System.currentTimeMillis();
		while (db == null && (System.currentTimeMillis() - start) < TimeUnit.MINUTES.toMillis(10)) {
			try {
				System.out.println("Waiting for connection");
				Thread.sleep(TimeUnit.SECONDS.toMillis(10));
				db = dataSource.getConnection();
				System.out.println("Connection obtained");
			} catch (SQLException e) {
				ex = e;
			} catch (InterruptedException e) {
				// ignore
			}
		}
		if (db == null) {
			throw ex;
		}
		System.out.println("After getConnection Src");
		try {
			db.createStatement().executeUpdate("drop table projects_src");
		} catch (Exception e) {
			// Ignore dropping of non-existent table
		}

		db.createStatement().executeUpdate("create table projects_src (id integer primary key," +
				"project varchar(10), license varchar(5), mandays integer)");
		db.createStatement().executeUpdate("insert into projects_src values (1, 'Camel', 'ASF', 5)");
		db.createStatement().executeUpdate("insert into projects_src values (2, 'AMQ', 'ASF', 10)");
		db.createStatement().executeUpdate("insert into projects_src values (3, 'Linux', 'XXX', 20)");
	}

	private void initDatabaseTrg(DataSource dataSource) throws SQLException {
		System.out.println("Before getConnection Trg");
		Connection db = dataSource.getConnection();
		System.out.println("After getConnection Trg");

		try {
			db.createStatement().executeUpdate("drop table projects_trg");
		} catch (Exception e) {
			// Ignore dropping of non-existent table
		}

		db.createStatement().executeUpdate("create table projects_trg (id integer primary key," +
				"project_license varchar(12), mandays integer)");
	}

	public void create() throws Exception {
		initDatabaseSrc(srcDataSource);
		initDatabaseTrg(trgDataSource);
	}

	public void destroy() throws Exception {

	}
}
